# Lawlor human pancreas (SMARTer)

<script>
document.addEventListener("click", function (event) {
    if (event.target.classList.contains("rebook-collapse")) {
        event.target.classList.toggle("active");
        var content = event.target.nextElementSibling;
        if (content.style.display === "block") {
            content.style.display = "none";
        } else {
            content.style.display = "block";
        }
    }
})
</script>

<style>
.rebook-collapse {
  background-color: #eee;
  color: #444;
  cursor: pointer;
  padding: 18px;
  width: 100%;
  border: none;
  text-align: left;
  outline: none;
  font-size: 15px;
}

.rebook-content {
  padding: 0 18px;
  display: none;
  overflow: hidden;
  background-color: #f1f1f1;
}
</style>

## Introduction

This performs an analysis of the @lawlor2017singlecell dataset,
consisting of human pancreas cells from various donors.

## Data loading


``` r
library(scRNAseq)
sce.lawlor <- LawlorPancreasData()
```


``` r
library(AnnotationHub)
edb <- AnnotationHub()[["AH73881"]]
anno <- select(edb, keys=rownames(sce.lawlor), keytype="GENEID", 
    columns=c("SYMBOL", "SEQNAME"))
rowData(sce.lawlor) <- anno[match(rownames(sce.lawlor), anno[,1]),-1]
```

## Quality control


``` r
unfiltered <- sce.lawlor
```


``` r
library(scater)
stats <- perCellQCMetrics(sce.lawlor, 
    subsets=list(Mito=which(rowData(sce.lawlor)$SEQNAME=="MT")))
qc <- quickPerCellQC(stats, percent_subsets="subsets_Mito_percent",
    batch=sce.lawlor$`islet unos id`)
sce.lawlor <- sce.lawlor[,!qc$discard]
```


``` r
colData(unfiltered) <- cbind(colData(unfiltered), stats)
unfiltered$discard <- qc$discard

gridExtra::grid.arrange(
    plotColData(unfiltered, x="islet unos id", y="sum", colour_by="discard") +
        scale_y_log10() + ggtitle("Total count") +
        theme(axis.text.x = element_text(angle = 90)),
    plotColData(unfiltered, x="islet unos id", y="detected", 
        colour_by="discard") + scale_y_log10() + ggtitle("Detected features") +
        theme(axis.text.x = element_text(angle = 90)), 
    plotColData(unfiltered, x="islet unos id", y="subsets_Mito_percent",
        colour_by="discard") + ggtitle("Mito percent") +
        theme(axis.text.x = element_text(angle = 90)),
    ncol=2
)
```

<div class="figure">
<img src="lawlor-pancreas_files/figure-html/unref-lawlor-qc-dist-1.png" alt="Distribution of each QC metric across cells from each donor of the Lawlor pancreas dataset. Each point represents a cell and is colored according to whether that cell was discarded." width="960" />
<p class="caption">(\#fig:unref-lawlor-qc-dist)Distribution of each QC metric across cells from each donor of the Lawlor pancreas dataset. Each point represents a cell and is colored according to whether that cell was discarded.</p>
</div>


``` r
plotColData(unfiltered, x="sum", y="subsets_Mito_percent",
    colour_by="discard") + scale_x_log10()
```

<div class="figure">
<img src="lawlor-pancreas_files/figure-html/unref-lawlor-qc-comp-1.png" alt="Percentage of mitochondrial reads in each cell in the 416B dataset compared to the total count. Each point represents a cell and is colored according to whether that cell was discarded." width="672" />
<p class="caption">(\#fig:unref-lawlor-qc-comp)Percentage of mitochondrial reads in each cell in the 416B dataset compared to the total count. Each point represents a cell and is colored according to whether that cell was discarded.</p>
</div>


``` r
colSums(as.matrix(qc))
```

```
##              low_lib_size            low_n_features high_subsets_Mito_percent 
##                         9                         5                        25 
##                   discard 
##                        34
```

## Normalization


``` r
library(scran)
set.seed(1000)
clusters <- quickCluster(sce.lawlor)
sce.lawlor <- computeSumFactors(sce.lawlor, clusters=clusters)
sce.lawlor <- logNormCounts(sce.lawlor)
```


``` r
summary(sizeFactors(sce.lawlor))
```

```
##    Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
##   0.295   0.781   0.963   1.000   1.182   2.629
```


``` r
plot(librarySizeFactors(sce.lawlor), sizeFactors(sce.lawlor), pch=16,
    xlab="Library size factors", ylab="Deconvolution factors", log="xy")
```

<div class="figure">
<img src="lawlor-pancreas_files/figure-html/unref-lawlor-norm-1.png" alt="Relationship between the library size factors and the deconvolution size factors in the Lawlor pancreas dataset." width="672" />
<p class="caption">(\#fig:unref-lawlor-norm)Relationship between the library size factors and the deconvolution size factors in the Lawlor pancreas dataset.</p>
</div>

## Variance modelling

Using age as a proxy for the donor.


``` r
dec.lawlor <- modelGeneVar(sce.lawlor, block=sce.lawlor$`islet unos id`)
chosen.genes <- getTopHVGs(dec.lawlor, n=2000)
```


``` r
par(mfrow=c(4,2))
blocked.stats <- dec.lawlor$per.block
for (i in colnames(blocked.stats)) {
    current <- blocked.stats[[i]]
    plot(current$mean, current$total, main=i, pch=16, cex=0.5,
        xlab="Mean of log-expression", ylab="Variance of log-expression")
    curfit <- metadata(current)
    curve(curfit$trend(x), col='dodgerblue', add=TRUE, lwd=2)
}
```

<div class="figure">
<img src="lawlor-pancreas_files/figure-html/unnamed-chunk-4-1.png" alt="Per-gene variance as a function of the mean for the log-expression values in the Lawlor pancreas dataset. Each point represents a gene (black) with the mean-variance trend (blue) fitted separately for each donor." width="672" />
<p class="caption">(\#fig:unnamed-chunk-4)Per-gene variance as a function of the mean for the log-expression values in the Lawlor pancreas dataset. Each point represents a gene (black) with the mean-variance trend (blue) fitted separately for each donor.</p>
</div>

## Dimensionality reduction


``` r
library(BiocSingular)
set.seed(101011001)
sce.lawlor <- runPCA(sce.lawlor, subset_row=chosen.genes, ncomponents=25)
sce.lawlor <- runTSNE(sce.lawlor, dimred="PCA")
```

## Clustering


``` r
snn.gr <- buildSNNGraph(sce.lawlor, use.dimred="PCA")
colLabels(sce.lawlor) <- factor(igraph::cluster_walktrap(snn.gr)$membership)
```


``` r
table(colLabels(sce.lawlor), sce.lawlor$`cell type`)
```

```
##    
##     Acinar Alpha Beta Delta Ductal Gamma/PP None/Other Stellate
##   1      1     0    1    13      2       16          2        0
##   2      0     0   75     1      0        0          0        0
##   3      0   161    1     0      0        1          2        0
##   4      0     1    0     1      0        0          5       19
##   5     22     0    0     0      0        0          0        0
##   6      0     0  174     4      1        0          1        0
##   7      0    76    1     0      0        0          0        0
##   8      0     0    0     1     20        0          2        0
```


``` r
table(colLabels(sce.lawlor), sce.lawlor$`islet unos id`)
```

```
##    
##     ACCG268 ACCR015A ACEK420A ACEL337 ACHY057 ACIB065 ACIW009 ACJV399
##   1       8        2        2       4       4       4       9       2
##   2      13        3        2      33       3       2       4      16
##   3      36       23       14      13      14      14      21      30
##   4       7        1        0       1       0       4       9       4
##   5       0        2       13       0       0       0       5       2
##   6      34       10        4      39       7      23      24      39
##   7      33       12        0       5       6       7       4      10
##   8       1        1        2       1       2       1      12       3
```


``` r
gridExtra::grid.arrange(
    plotTSNE(sce.lawlor, colour_by="label"),
    plotTSNE(sce.lawlor, colour_by="islet unos id"),
    ncol=2
)
```

<div class="figure">
<img src="lawlor-pancreas_files/figure-html/unref-grun-tsne-1.png" alt="Obligatory $t$-SNE plots of the Lawlor pancreas dataset. Each point represents a cell that is colored by cluster (left) or batch (right)." width="672" />
<p class="caption">(\#fig:unref-grun-tsne)Obligatory $t$-SNE plots of the Lawlor pancreas dataset. Each point represents a cell that is colored by cluster (left) or batch (right).</p>
</div>

## Session Info {-}

<button class="rebook-collapse">View session info</button>
<div class="rebook-content">
```
R version 4.5.0 RC (2025-04-04 r88126)
Platform: x86_64-pc-linux-gnu
Running under: Ubuntu 24.04.2 LTS

Matrix products: default
BLAS:   /home/biocbuild/bbs-3.21-bioc/R/lib/libRblas.so 
LAPACK: /usr/lib/x86_64-linux-gnu/lapack/liblapack.so.3.12.0  LAPACK version 3.12.0

locale:
 [1] LC_CTYPE=en_US.UTF-8       LC_NUMERIC=C              
 [3] LC_TIME=en_GB              LC_COLLATE=C              
 [5] LC_MONETARY=en_US.UTF-8    LC_MESSAGES=en_US.UTF-8   
 [7] LC_PAPER=en_US.UTF-8       LC_NAME=C                 
 [9] LC_ADDRESS=C               LC_TELEPHONE=C            
[11] LC_MEASUREMENT=en_US.UTF-8 LC_IDENTIFICATION=C       

time zone: America/New_York
tzcode source: system (glibc)

attached base packages:
[1] stats4    stats     graphics  grDevices utils     datasets  methods  
[8] base     

other attached packages:
 [1] BiocSingular_1.24.0         scran_1.36.0               
 [3] scater_1.36.0               ggplot2_3.5.2              
 [5] scuttle_1.18.0              ensembldb_2.32.0           
 [7] AnnotationFilter_1.32.0     GenomicFeatures_1.60.0     
 [9] AnnotationDbi_1.70.0        AnnotationHub_3.16.0       
[11] BiocFileCache_2.16.0        dbplyr_2.5.0               
[13] scRNAseq_2.21.1             SingleCellExperiment_1.30.0
[15] SummarizedExperiment_1.38.0 Biobase_2.68.0             
[17] GenomicRanges_1.60.0        GenomeInfoDb_1.44.0        
[19] IRanges_2.42.0              S4Vectors_0.46.0           
[21] BiocGenerics_0.54.0         generics_0.1.3             
[23] MatrixGenerics_1.20.0       matrixStats_1.5.0          
[25] BiocStyle_2.36.0            rebook_1.18.0              

loaded via a namespace (and not attached):
  [1] jsonlite_2.0.0           CodeDepends_0.6.6        magrittr_2.0.3          
  [4] ggbeeswarm_0.7.2         gypsum_1.4.0             farver_2.1.2            
  [7] rmarkdown_2.29           BiocIO_1.18.0            vctrs_0.6.5             
 [10] memoise_2.0.1            Rsamtools_2.24.0         RCurl_1.98-1.17         
 [13] htmltools_0.5.8.1        S4Arrays_1.8.0           curl_6.2.2              
 [16] BiocNeighbors_2.2.0      Rhdf5lib_1.30.0          SparseArray_1.8.0       
 [19] rhdf5_2.52.0             sass_0.4.10              alabaster.base_1.8.0    
 [22] bslib_0.9.0              alabaster.sce_1.8.0      httr2_1.1.2             
 [25] cachem_1.1.0             GenomicAlignments_1.44.0 igraph_2.1.4            
 [28] mime_0.13                lifecycle_1.0.4          pkgconfig_2.0.3         
 [31] rsvd_1.0.5               Matrix_1.7-3             R6_2.6.1                
 [34] fastmap_1.2.0            GenomeInfoDbData_1.2.14  digest_0.6.37           
 [37] colorspace_2.1-1         dqrng_0.4.1              irlba_2.3.5.1           
 [40] ExperimentHub_2.16.0     RSQLite_2.3.9            beachmat_2.24.0         
 [43] labeling_0.4.3           filelock_1.0.3           httr_1.4.7              
 [46] abind_1.4-8              compiler_4.5.0           bit64_4.6.0-1           
 [49] withr_3.0.2              BiocParallel_1.42.0      viridis_0.6.5           
 [52] DBI_1.2.3                HDF5Array_1.36.0         alabaster.ranges_1.8.0  
 [55] alabaster.schemas_1.8.0  rappdirs_0.3.3           DelayedArray_0.34.0     
 [58] bluster_1.18.0           rjson_0.2.23             tools_4.5.0             
 [61] vipor_0.4.7              beeswarm_0.4.0           glue_1.8.0              
 [64] h5mread_1.0.0            restfulr_0.0.15          rhdf5filters_1.20.0     
 [67] grid_4.5.0               Rtsne_0.17               cluster_2.1.8.1         
 [70] gtable_0.3.6             metapod_1.16.0           ScaledMatrix_1.16.0     
 [73] XVector_0.48.0           ggrepel_0.9.6            BiocVersion_3.21.1      
 [76] pillar_1.10.2            limma_3.64.0             dplyr_1.1.4             
 [79] lattice_0.22-7           rtracklayer_1.68.0       bit_4.6.0               
 [82] tidyselect_1.2.1         locfit_1.5-9.12          Biostrings_2.76.0       
 [85] knitr_1.50               gridExtra_2.3            bookdown_0.43           
 [88] ProtGenerics_1.40.0      edgeR_4.6.0              xfun_0.52               
 [91] statmod_1.5.0            UCSC.utils_1.4.0         lazyeval_0.2.2          
 [94] yaml_2.3.10              evaluate_1.0.3           codetools_0.2-20        
 [97] tibble_3.2.1             alabaster.matrix_1.8.0   BiocManager_1.30.25     
[100] graph_1.86.0             cli_3.6.4                munsell_0.5.1           
[103] jquerylib_0.1.4          Rcpp_1.0.14              dir.expiry_1.16.0       
[106] png_0.1-8                XML_3.99-0.18            parallel_4.5.0          
[109] blob_1.2.4               bitops_1.0-9             viridisLite_0.4.2       
[112] alabaster.se_1.8.0       scales_1.3.0             purrr_1.0.4             
[115] crayon_1.5.3             rlang_1.1.6              cowplot_1.1.3           
[118] KEGGREST_1.48.0         
```
</div>
